Release Notes
=============

0.1
---

Initial relase of Zinnia Drupal. Contains full support for:

* Importing users.
* Importing categories (Drupal vocabularies).
* Importing content.
* Importing comments.

0.1.1
-----

Patch release for fixing some naming in documentation. No changes in
functionality.

0.1.2
-----

Minor packaging changes in order to allow upload to PyPI.
